Tips
----

.. include:: tips/configuration.rst
.. include:: tips/updates.rst
.. include:: tips/errors.rst
.. include:: tips/affiliations.rst
.. include:: tips/rename.rst
.. include:: tips/migration1.rst
